@@ -7,14 +7,20 @@ var (
 	ConnectorTypes  = []string{"tcp"}
 	WorkloadTypes   = []string{"deployment", "service", "daemonset", "statefulset"}
 	WaitStatusTypes = []string{"ready", "configured", "none"}
+	BundleTypes     = []string{"tarball", "shell-script"}
 )
 
 const (
-	Connectors     string = "Connector"
-	Listeners      string = "Listener"
-	Sites          string = "Site"
-	RouterAccesses string = "RouterAccess"
-	Links          string = "Link"
+	Connectors      string = "Connector"
+	Listeners       string = "Listener"
+	Sites           string = "Site"
+	RouterAccesses  string = "RouterAccess"
+	Links           string = "Link"
+	AccessTokens    string = "AccessToken"
+	Secrets         string = "Secret"
+	ConfigMaps      string = "ConfigMap"
+	Certificates    string = "Certificate"
+	SecuredAccesses string = "SecuredAccess"
 )
 
 const (
