@@ -5,6 +5,7 @@ import (
 	"errors"
 	"fmt"
 	"os"
+	"path/filepath"
 	"strconv"
 
 	"github.com/skupperproject/skupper/internal/cmd/skupper/common"
@@ -51,6 +52,13 @@ func (cmd *CmdTokenIssue) ValidateInput(args []string) error {
 	expirationValidator := validator.NewExpirationInSecondsValidator()
 	numberValidator := validator.NewNumberValidator()
 
+	// Validate if AccessGrant CRD is installed
+	_, err := cmd.client.AccessGrants(cmd.namespace).List(context.TODO(), metav1.ListOptions{})
+	if err != nil {
+		validationErrors = append(validationErrors, utils.HandleMissingCrds(err))
+		return errors.Join(validationErrors...)
+	}
+
 	// Validate token file name
 	if len(args) < 1 {
 		validationErrors = append(validationErrors, fmt.Errorf("file name must be configured"))
@@ -63,16 +71,29 @@ func (cmd *CmdTokenIssue) ValidateInput(args []string) error {
 		if !ok {
 			validationErrors = append(validationErrors, fmt.Errorf("token file name is not valid: %s", err))
 		} else {
-			// check we can use as a filename
-			if _, err := os.ReadDir(args[0]); err == nil {
+			// check filename and directory are valid to create the token
+			if fileInfo, err := os.Stat(args[0]); err == nil && fileInfo.IsDir() {
 				validationErrors = append(validationErrors, fmt.Errorf("token file name is a directory"))
+			} else {
+				directory, filename := filepath.Split(args[0])
+				// test token can be create in directory
+				file, err := os.CreateTemp(directory, filename)
+				if err != nil {
+					validationErrors = append(validationErrors, fmt.Errorf("invalid token file name: %s", errors.Unwrap(err)))
+				} else {
+					os.Remove(file.Name())
+				}
 			}
 			cmd.fileName = args[0]
 		}
 	}
 
-	// Validate there is already a site defined in the namespace before a token can be created
-	siteList, _ := cmd.client.Sites(cmd.namespace).List(context.TODO(), metav1.ListOptions{})
+	// Validate Site CRD is installed and there is already a site defined in the namespace before a token can be created
+	siteList, err := cmd.client.Sites(cmd.namespace).List(context.TODO(), metav1.ListOptions{})
+	if err != nil {
+		validationErrors = append(validationErrors, utils.HandleMissingCrds(err))
+		return errors.Join(validationErrors...)
+	}
 	if siteList == nil || len(siteList.Items) == 0 {
 		validationErrors = append(validationErrors, fmt.Errorf("A site must exist in namespace %s before a token can be created", cmd.namespace))
 	} else {
