@@ -8,7 +8,6 @@ import (
 	"log/slog"
 	"os"
 	"regexp"
-	"strings"
 
 	appsv1 "k8s.io/api/apps/v1"
 	corev1 "k8s.io/api/core/v1"
@@ -23,7 +22,9 @@ import (
 	"github.com/skupperproject/skupper/internal/kube/site"
 	"github.com/skupperproject/skupper/internal/kube/site/labels"
 	"github.com/skupperproject/skupper/internal/kube/site/sizing"
+	"github.com/skupperproject/skupper/internal/kube/watchers"
 	"github.com/skupperproject/skupper/internal/network"
+	"github.com/skupperproject/skupper/internal/qdr"
 	"github.com/skupperproject/skupper/internal/version"
 	skupperv2alpha1 "github.com/skupperproject/skupper/pkg/apis/skupper/v2alpha1"
 )
@@ -32,27 +33,32 @@ type Controller struct {
 	self                 skupperv2alpha1.Controller
 	deploymentName       string
 	deploymentUid        string
-	controller           *internalclient.Controller
+	eventProcessor       *watchers.EventProcessor
 	stopCh               <-chan struct{}
-	siteWatcher          *internalclient.SiteWatcher
-	listenerWatcher      *internalclient.ListenerWatcher
-	connectorWatcher     *internalclient.ConnectorWatcher
-	linkAccessWatcher    *internalclient.RouterAccessWatcher
-	grantWatcher         *internalclient.AccessGrantWatcher
+	siteWatcher          *watchers.SiteWatcher
+	listenerWatcher      *watchers.ListenerWatcher
+	connectorWatcher     *watchers.ConnectorWatcher
+	linkAccessWatcher    *watchers.RouterAccessWatcher
+	grantWatcher         *watchers.AccessGrantWatcher
 	sites                map[string]*site.Site
 	startGrantServer     func()
 	accessMgr            *securedaccess.SecuredAccessManager
 	accessRecovery       *securedaccess.SecuredAccessResourceWatcher
 	certMgr              *certificates.CertificateManagerImpl
 	siteSizing           *sizing.Registry
-	siteSizingWatcher    *internalclient.ConfigMapWatcher
+	siteSizingWatcher    *watchers.ConfigMapWatcher
 	labelling            *labels.LabelsAndAnnotations
-	labellingWatcher     *internalclient.ConfigMapWatcher
+	labellingWatcher     *watchers.ConfigMapWatcher
 	attachableConnectors map[string]*skupperv2alpha1.AttachedConnector
 	log                  *slog.Logger
 	namespaces           *NamespaceConfig
 }
 
+func skupperRouterConfig() internalinterfaces.TweakListOptionsFunc {
+	return func(options *metav1.ListOptions) {
+		options.LabelSelector = "internal.skupper.io/router-config"
+	}
+}
 func skupperNetworkStatus() internalinterfaces.TweakListOptionsFunc {
 	return func(options *metav1.ListOptions) {
 		options.FieldSelector = "metadata.name=skupper-network-status"
@@ -79,7 +85,7 @@ func labelling() internalinterfaces.TweakListOptionsFunc {
 
 func NewController(cli internalclient.Clients, config *Config) (*Controller, error) {
 	controller := &Controller{
-		controller:           internalclient.NewController("Controller", cli),
+		eventProcessor:       watchers.NewEventProcessor("Controller", cli),
 		sites:                map[string]*site.Site{},
 		siteSizing:           sizing.NewRegistry(),
 		labelling:            labels.NewLabelsAndAnnotations(config.Namespace),
@@ -111,34 +117,35 @@ func NewController(cli internalclient.Clients, config *Config) (*Controller, err
 	controller.self.Namespace = config.Namespace
 	controller.self.Version = version.Version
 
-	controller.siteWatcher = controller.controller.WatchSites(config.WatchNamespace, filter(controller, controller.checkSite))
-	controller.listenerWatcher = controller.controller.WatchListeners(config.WatchNamespace, filter(controller, controller.checkListener))
-	controller.controller.WatchServices(listenerServices(), config.WatchNamespace, filter(controller, controller.checkListenerService))
-	controller.connectorWatcher = controller.controller.WatchConnectors(config.WatchNamespace, filter(controller, controller.checkConnector))
-	controller.linkAccessWatcher = controller.controller.WatchRouterAccesses(config.WatchNamespace, filter(controller, controller.checkRouterAccess))
-	controller.controller.WatchAttachedConnectors(config.WatchNamespace, filter(controller, controller.checkAttachedConnector))
-	controller.controller.WatchAttachedConnectorBindings(config.WatchNamespace, filter(controller, controller.checkAttachedConnectorBinding))
-	controller.controller.WatchLinks(config.WatchNamespace, filter(controller, controller.checkLink))
-	controller.controller.WatchConfigMaps(skupperNetworkStatus(), config.WatchNamespace, filter(controller, controller.networkStatusUpdate))
-	controller.controller.WatchAccessTokens(config.WatchNamespace, filter(controller, controller.checkAccessToken))
-	controller.controller.WatchPods("skupper.io/component=router,skupper.io/type=site", config.WatchNamespace, filter(controller, controller.routerPodEvent))
-	controller.siteSizingWatcher = controller.controller.WatchConfigMaps(skupperSiteSizingConfig(), config.Namespace, filter(controller, controller.siteSizing.Update))
-	controller.namespaces.watch(controller.controller, config.WatchNamespace)
-	controller.labellingWatcher = controller.controller.WatchConfigMaps(labelling(), config.WatchNamespace, controller.labelling.Update)
+	controller.siteWatcher = controller.eventProcessor.WatchSites(config.WatchNamespace, filter(controller, controller.checkSite))
+	controller.listenerWatcher = controller.eventProcessor.WatchListeners(config.WatchNamespace, filter(controller, controller.checkListener))
+	controller.eventProcessor.WatchServices(listenerServices(), config.WatchNamespace, filter(controller, controller.checkListenerService))
+	controller.connectorWatcher = controller.eventProcessor.WatchConnectors(config.WatchNamespace, filter(controller, controller.checkConnector))
+	controller.linkAccessWatcher = controller.eventProcessor.WatchRouterAccesses(config.WatchNamespace, filter(controller, controller.checkRouterAccess))
+	controller.eventProcessor.WatchAttachedConnectors(config.WatchNamespace, filter(controller, controller.checkAttachedConnector))
+	controller.eventProcessor.WatchAttachedConnectorBindings(config.WatchNamespace, filter(controller, controller.checkAttachedConnectorBinding))
+	controller.eventProcessor.WatchLinks(config.WatchNamespace, filter(controller, controller.checkLink))
+	controller.eventProcessor.WatchConfigMaps(skupperNetworkStatus(), config.WatchNamespace, filter(controller, controller.networkStatusUpdate))
+	controller.eventProcessor.WatchConfigMaps(skupperRouterConfig(), config.WatchNamespace, filter(controller, controller.routerConfigUpdate))
+	controller.eventProcessor.WatchAccessTokens(config.WatchNamespace, filter(controller, controller.checkAccessToken))
+	controller.eventProcessor.WatchPods("skupper.io/component=router,skupper.io/type=site", config.WatchNamespace, filter(controller, controller.routerPodEvent))
+	controller.siteSizingWatcher = controller.eventProcessor.WatchConfigMaps(skupperSiteSizingConfig(), config.Namespace, filter(controller, controller.siteSizing.Update))
+	controller.namespaces.watch(controller.eventProcessor, config.WatchNamespace)
+	controller.labellingWatcher = controller.eventProcessor.WatchConfigMaps(labelling(), config.WatchNamespace, controller.labelling.Update)
 
-	controller.certMgr = certificates.NewCertificateManager(controller.controller)
+	controller.certMgr = certificates.NewCertificateManager(controller.eventProcessor)
 	controller.certMgr.SetControllerContext(controller)
 	controller.certMgr.Watch(config.WatchNamespace)
 
-	controller.accessMgr = securedaccess.NewSecuredAccessManager(controller.controller, controller.certMgr, config.SecuredAccessConfig, controller)
+	controller.accessMgr = securedaccess.NewSecuredAccessManager(controller.eventProcessor, controller.certMgr, config.SecuredAccessConfig, controller)
 	controller.accessRecovery = securedaccess.NewSecuredAccessResourceWatcher(controller.accessMgr)
-	controller.accessRecovery.WatchResources(controller.controller, config.WatchNamespace)
-	controller.accessRecovery.WatchSecuredAccesses(controller.controller, config.WatchNamespace, controller.checkSecuredAccess)
-	controller.accessRecovery.WatchGateway(controller.controller, config.Namespace)
+	controller.accessRecovery.WatchResources(controller.eventProcessor, config.WatchNamespace)
+	controller.accessRecovery.WatchSecuredAccesses(controller.eventProcessor, config.WatchNamespace, controller.checkSecuredAccess)
+	controller.accessRecovery.WatchGateway(controller.eventProcessor, config.Namespace)
 
-	controller.startGrantServer = grants.Initialise(controller.controller, config.Namespace, config.WatchNamespace, config.GrantConfig, controller.generateLinkConfig, controller.IsControlled)
+	controller.startGrantServer = grants.Initialise(controller.eventProcessor, config.Namespace, config.WatchNamespace, config.GrantConfig, controller.generateLinkConfig, controller.IsControlled)
 
-	controller.controller.WatchConfigMaps(skupperLogConfig(), config.Namespace, controller.logConfigUpdate)
+	controller.eventProcessor.WatchConfigMaps(skupperLogConfig(), config.Namespace, controller.logConfigUpdate)
 
 	return controller, nil
 }
@@ -174,7 +181,7 @@ func (c *Controller) getDeploymentForPod(podName string, namespace string) (*app
 		return nil, fmt.Errorf("Could not determine deployment name from %s", podName)
 	}
 	deploymentName := matches[1]
-	deployment, err := c.controller.GetKubeClient().AppsV1().Deployments(namespace).Get(context.TODO(), deploymentName, metav1.GetOptions{})
+	deployment, err := c.eventProcessor.GetKubeClient().AppsV1().Deployments(namespace).Get(context.TODO(), deploymentName, metav1.GetOptions{})
 	if err != nil {
 		return nil, fmt.Errorf("Failed to retrieve controller deployment for %s/%s: %s", namespace, deploymentName, err)
 	}
@@ -190,11 +197,11 @@ func (c *Controller) Run(stopCh <-chan struct{}) error {
 
 func (c *Controller) init(stopCh <-chan struct{}) error {
 	c.log.Info("Starting informers")
-	c.controller.StartWatchers(stopCh)
+	c.eventProcessor.StartWatchers(stopCh)
 	c.stopCh = stopCh
 
 	c.log.Info("Waiting for informer caches to sync")
-	if ok := c.controller.WaitForCacheSync(stopCh); !ok {
+	if ok := c.eventProcessor.WaitForCacheSync(stopCh); !ok {
 		return fmt.Errorf("Failed to wait for caches to sync")
 	}
 	c.namespaces.recover()
@@ -214,7 +221,7 @@ func (c *Controller) init(stopCh <-chan struct{}) error {
 		c.labelling.Update(config.Namespace+"/"+config.Name, config)
 	}
 	//recover existing sites & bindings
-	siteRecovery := site.NewSiteRecovery(c.controller.GetKubeClient())
+	siteRecovery := site.NewSiteRecovery(c.eventProcessor.GetKubeClient())
 	for _, site := range c.siteWatcher.List() {
 		if !c.namespaces.isControlled(site.Namespace) {
 			continue
@@ -301,7 +308,7 @@ func (c *Controller) init(stopCh <-chan struct{}) error {
 
 func (c *Controller) start(stopCh <-chan struct{}) error {
 	c.log.Info("Starting event loop")
-	c.controller.Start(stopCh)
+	c.eventProcessor.Start(stopCh)
 	<-stopCh
 	c.log.Info("Shutting down")
 	return nil
@@ -311,7 +318,7 @@ func (c *Controller) getSite(namespace string) *site.Site {
 	if existing, ok := c.sites[namespace]; ok {
 		return existing
 	}
-	site := site.NewSite(namespace, c.controller, c.certMgr, c.accessMgr, c.siteSizing, c)
+	site := site.NewSite(namespace, c.eventProcessor, c.certMgr, c.accessMgr, c.siteSizing, c)
 	c.sites[namespace] = site
 	return site
 }
@@ -387,7 +394,7 @@ func (c *Controller) checkAccessToken(key string, token *skupperv2alpha1.AccessT
 	if site == nil {
 		return nil
 	}
-	return grants.RedeemAccessToken(token, site, c.controller)
+	return grants.RedeemAccessToken(token, site, c.eventProcessor)
 }
 
 func (c *Controller) routerPodEvent(key string, pod *corev1.Pod) error {
@@ -403,11 +410,14 @@ func (c *Controller) generateLinkConfig(namespace string, name string, subject s
 	if site == nil {
 		return fmt.Errorf("Site not yet defined for %s", namespace)
 	}
-	generator, err := grants.NewTokenGenerator(site, c.controller)
+	generator, err := grants.NewTokenGenerator(site, c.eventProcessor)
+	if err != nil {
+		return err
+	}
+	token, err := generator.NewCertToken(name, subject)
 	if err != nil {
 		return err
 	}
-	token := generator.NewCertToken(name, subject)
 	return token.Write(writer)
 }
 
@@ -444,6 +454,17 @@ func (c *Controller) checkAttachedConnector(key string, connector *skupperv2alph
 		return c.getSite(connector.Spec.SiteNamespace).AttachedConnectorUpdated(connector)
 	}
 }
+func (c *Controller) routerConfigUpdate(_ string, cm *corev1.ConfigMap) error {
+	if cm == nil {
+		return nil
+	}
+	config, err := qdr.GetRouterConfigFromConfigMap(cm)
+	if err != nil {
+		return err
+	}
+	c.getSite(cm.Namespace).CheckSslProfiles(config)
+	return nil
+}
 
 func (c *Controller) networkStatusUpdate(key string, cm *corev1.ConfigMap) error {
 	if cm == nil {
@@ -461,80 +482,9 @@ func (c *Controller) networkStatusUpdate(key string, cm *corev1.ConfigMap) error
 		return nil
 	}
 	c.log.Debug("Updating network status", slog.String("site", key))
-	return c.getSite(cm.ObjectMeta.Namespace).NetworkStatusUpdated(extractSiteRecords(status))
-}
-
-func extractSiteRecords(status network.NetworkStatusInfo) []skupperv2alpha1.SiteRecord {
-	var records []skupperv2alpha1.SiteRecord
-	routerAPs := map[string]string{} // router access point ID -> site ID
-	siteNames := map[string]string{} // site ID -> site name
-	for _, site := range status.SiteStatus {
-		siteNames[site.Site.Identity] = site.Site.Name
-		for _, router := range site.RouterStatus {
-			for _, ap := range router.AccessPoints {
-				routerAPs[ap.Identity] = site.Site.Identity
-			}
-		}
-	}
-	for _, site := range status.SiteStatus {
-		record := skupperv2alpha1.SiteRecord{
-			Id:        site.Site.Identity,
-			Name:      site.Site.Name,
-			Platform:  site.Site.Platform,
-			Namespace: site.Site.Namespace,
-			Version:   site.Site.Version,
-		}
-		services := map[string]*skupperv2alpha1.ServiceRecord{}
-		for _, router := range site.RouterStatus {
-			for _, link := range router.Links {
-				if link.Name == "" || link.Peer == "" {
-					continue
-				}
-
-				if site, ok := routerAPs[link.Peer]; ok {
-					record.Links = append(record.Links, skupperv2alpha1.LinkRecord{
-						Name:           link.Name,
-						RemoteSiteId:   site,
-						RemoteSiteName: siteNames[site],
-						Operational:    strings.EqualFold(link.Status, "up"),
-					})
-				}
-			}
-			for _, connector := range router.Connectors {
-				if connector.Address != "" && connector.DestHost != "" {
-					address := connector.Address
-					service, ok := services[address]
-					if !ok {
-						service = &skupperv2alpha1.ServiceRecord{
-							RoutingKey: address,
-						}
-						services[address] = service
-					}
-					service.Connectors = append(service.Connectors, connector.DestHost)
-				}
-			}
-			for _, listener := range router.Listeners {
-				if listener.Address != "" && listener.Name != "" {
-					address := listener.Address
-					service, ok := services[address]
-					if !ok {
-						service = &skupperv2alpha1.ServiceRecord{
-							RoutingKey: address,
-						}
-						services[address] = service
-					}
-					service.Listeners = append(service.Listeners, listener.Name)
-				}
-			}
-		}
-		for _, service := range services {
-			record.Services = append(record.Services, *service)
-		}
-		records = append(records, record)
-	}
-	return records
+	return c.getSite(cm.ObjectMeta.Namespace).NetworkStatusUpdated(network.ExtractSiteRecords(status))
 }
 
 func filter[V any](controller *Controller, handler func(string, V) error) func(string, V) error {
-	return internalclient.FilterByNamespace(controller.IsControlled, handler)
+	return watchers.FilterByNamespace(controller.IsControlled, handler)
 }
