@@ -508,11 +508,11 @@ func TestGeneral(t *testing.T) {
 			err = controller.init(stopCh)
 			assert.Assert(t, err)
 			for i := 0; i < len(tt.k8sObjects)+len(tt.skupperObjects); i++ {
-				controller.controller.TestProcess()
+				controller.eventProcessor.TestProcess()
 			}
 			for _, wf := range tt.waitFunctions {
 				for !wf(t, clients) {
-					controller.controller.TestProcess()
+					controller.eventProcessor.TestProcess()
 				}
 			}
 			for _, expected := range tt.expectedSiteStatuses {
@@ -660,12 +660,12 @@ func TestUpdate(t *testing.T) {
 			err = controller.init(stopCh)
 			assert.Assert(t, err)
 			for i := 0; i < len(tt.k8sObjects)+len(tt.skupperObjects); i++ {
-				controller.controller.TestProcess()
+				controller.eventProcessor.TestProcess()
 			}
 
 			for _, f := range tt.functions {
 				for !f(t, clients) {
-					controller.controller.TestProcess()
+					controller.eventProcessor.TestProcess()
 				}
 			}
 		})
@@ -673,6 +673,7 @@ func TestUpdate(t *testing.T) {
 }
 
 func verifyStatus(t *testing.T, expected skupperv2alpha1.Status, actual skupperv2alpha1.Status) {
+	t.Helper()
 	assert.Equal(t, expected.StatusType, actual.StatusType, actual.Message)
 	assert.Equal(t, expected.Message, actual.Message)
 	for _, condition := range expected.Conditions {
@@ -1343,7 +1344,7 @@ func (*factory) podCondition(conditionType corev1.PodConditionType, status corev
 
 func (*factory) addNetworkStatus(site *skupperv2alpha1.Site, status *NetworkStatus) *skupperv2alpha1.Site {
 	//add equivalent data to that generated in networkStatusInfo
-	site.Status.Network = extractSiteRecords(*status.info())
+	site.Status.Network = network.ExtractSiteRecords(*status.info())
 	return site
 }
 
