@@ -123,15 +123,24 @@ func compareCertificates(t *testing.T, customOutputPath string) {
 func createInputCertificates(t *testing.T, customOutputPath string) {
 	// preparing certificates
 	fakeHosts := "10.0.0.1,10.0.0.2,fake.domain"
-	ca := certs.GenerateCASecret("fake-ca", "fake-ca")
-	server := certs.GenerateSecret("fake-server-cert", "fake-server-cert", fakeHosts, &ca)
-	client := certs.GenerateSecret("fake-client-cert", "fake-client-cert", "", &ca)
+	ca, err := certs.GenerateSecret("fake-ca", "fake-ca", "", 0, nil)
+	if err != nil {
+		t.Error(err)
+	}
+	server, err := certs.GenerateSecret("fake-server-cert", "fake-server-cert", fakeHosts, 0, ca)
+	if err != nil {
+		t.Error(err)
+	}
+	client, err := certs.GenerateSecret("fake-client-cert", "fake-client-cert", "", 0, ca)
+	if err != nil {
+		t.Error(err)
+	}
 
 	// paths for each provided certificate
 	caPath := path.Join(customOutputPath, "namespaces/default", string(api.InputIssuersPath), "skupper-site-ca")
 	serverPath := path.Join(customOutputPath, "namespaces/default", string(api.InputCertificatesPath), "link-access-one")
 	clientPath := path.Join(customOutputPath, "namespaces/default", string(api.InputCertificatesPath), "client-link-access-one")
-	certsMap := map[string]corev1.Secret{
+	certsMap := map[string]*corev1.Secret{
 		caPath:     ca,
 		serverPath: server,
 		clientPath: client,
@@ -286,5 +295,6 @@ func fakeSiteState() *api.SiteState {
 		Claims:          make(map[string]*v2alpha1.AccessToken),
 		Certificates:    make(map[string]*v2alpha1.Certificate),
 		SecuredAccesses: make(map[string]*v2alpha1.SecuredAccess),
+		ConfigMaps:      make(map[string]*corev1.ConfigMap),
 	}
 }
