@@ -371,10 +371,35 @@ type RouterMetadata struct {
 }
 
 type SslProfile struct {
-	Name           string `json:"name,omitempty"`
-	CertFile       string `json:"certFile,omitempty"`
-	PrivateKeyFile string `json:"privateKeyFile,omitempty"`
-	CaCertFile     string `json:"caCertFile,omitempty"`
+	Name               string `json:"name,omitempty"`
+	CertFile           string `json:"certFile,omitempty"`
+	PrivateKeyFile     string `json:"privateKeyFile,omitempty"`
+	CaCertFile         string `json:"caCertFile,omitempty"`
+	Ordinal            uint64 `json:"ordinal,omitempty"`
+	OldestValidOrdinal uint64 `json:"oldestValidOrdinal,omitempty"`
+}
+
+func (p SslProfile) toRecord() Record {
+	result := make(map[string]any)
+	if p.Name != "" {
+		result["name"] = p.Name
+	}
+	if p.CertFile != "" {
+		result["certFile"] = p.CertFile
+	}
+	if p.PrivateKeyFile != "" {
+		result["privateKeyFile"] = p.PrivateKeyFile
+	}
+	if p.CaCertFile != "" {
+		result["caCertFile"] = p.CaCertFile
+	}
+	if p.Ordinal > 0 {
+		result["ordinal"] = p.Ordinal
+	}
+	if p.OldestValidOrdinal > 0 {
+		result["oldestValidOrdinal"] = p.OldestValidOrdinal
+	}
+	return result
 }
 
 type LogConfig struct {
@@ -402,6 +427,54 @@ type Listener struct {
 	MaxSessionFrames int    `json:"maxSessionFrames,omitempty" yaml:"max-session-frames,omitempty"`
 }
 
+func (listener Listener) toRecord() Record {
+	record := map[string]any{}
+	record["name"] = listener.Name
+	record["role"] = string(listener.Role)
+	record["host"] = listener.Host
+	record["port"] = strconv.Itoa(int(listener.Port))
+	if listener.Cost > 0 {
+		record["cost"] = listener.Cost
+	}
+	if listener.LinkCapacity > 0 {
+		record["linkCapacity"] = listener.LinkCapacity
+	}
+	if len(listener.SslProfile) > 0 {
+		record["sslProfile"] = listener.SslProfile
+	}
+	if listener.AuthenticatePeer {
+		record["authenticatePeer"] = listener.AuthenticatePeer
+	}
+	if len(listener.SaslMechanisms) > 0 {
+		record["saslMechanisms"] = listener.SaslMechanisms
+	}
+	if listener.MaxFrameSize > 0 {
+		record["maxFrameSize"] = listener.MaxFrameSize
+	}
+	if listener.MaxSessionFrames > 0 {
+		record["maxSessionFrames"] = listener.MaxSessionFrames
+	}
+	if listener.RouteContainer {
+		record["routeContainer"] = listener.RouteContainer
+	}
+	if listener.Http {
+		record["http"] = listener.Http
+	}
+	if len(listener.HttpRootDir) > 0 {
+		record["httpRootDir"] = listener.HttpRootDir
+	}
+	if listener.Websockets {
+		record["websockets"] = listener.Websockets
+	}
+	if listener.Healthz {
+		record["healthz"] = listener.Healthz
+	}
+	if listener.Metrics {
+		record["metrics"] = listener.Metrics
+	}
+
+	return record
+}
 func (l *Listener) SetMaxFrameSize(value int) {
 	l.MaxFrameSize = value
 }
@@ -424,6 +497,27 @@ type Connector struct {
 	MaxSessionFrames int    `json:"maxSessionFrames,omitempty"`
 }
 
+func (connector Connector) toRecord() Record {
+	record := map[string]any{}
+	record["name"] = connector.Name
+	record["role"] = string(connector.Role)
+	record["host"] = connector.Host
+	record["port"] = connector.Port
+	if connector.Cost > 0 {
+		record["cost"] = connector.Cost
+	}
+	if len(connector.SslProfile) > 0 {
+		record["sslProfile"] = connector.SslProfile
+	}
+	if connector.MaxFrameSize > 0 {
+		record["maxFrameSize"] = connector.MaxFrameSize
+	}
+	if connector.MaxSessionFrames > 0 {
+		record["maxSessionFrames"] = connector.MaxSessionFrames
+	}
+	return record
+}
+
 func (c *Connector) SetMaxFrameSize(value int) {
 	c.MaxFrameSize = value
 }
@@ -456,6 +550,35 @@ type TcpEndpoint struct {
 	ProcessID      string `json:"processId,omitempty"`
 }
 
+func (e TcpEndpoint) toRecord() Record {
+	result := make(map[string]any)
+	if e.Name != "" {
+		result["name"] = e.Name
+	}
+	if e.Host != "" {
+		result["host"] = e.Host
+	}
+	if e.Port != "" {
+		result["port"] = e.Port
+	}
+	if e.Address != "" {
+		result["address"] = e.Address
+	}
+	if e.SiteId != "" {
+		result["siteId"] = e.SiteId
+	}
+	if e.SslProfile != "" {
+		result["sslProfile"] = e.SslProfile
+	}
+	if e.VerifyHostname != nil {
+		result["verifyHostname"] = e.VerifyHostname
+	}
+	if e.ProcessID != "" {
+		result["processId"] = e.ProcessID
+	}
+	return result
+}
+
 type SiteConfig struct {
 	Name      string `json:"name,omitempty"`
 	Location  string `json:"location,omitempty"`
@@ -701,8 +824,14 @@ func (r *RouterConfig) UpdateConfigMap(configmap *corev1.ConfigMap) (bool, error
 
 type ListenerPredicate func(Listener) bool
 
-func IsNotNormalListener(l Listener) bool {
-	return l.Role != "normal" && l.Role != ""
+func IsNotProtectedListener(l Listener) bool {
+	protectedNames := [3]string{"@9090", "amqp", "amqps"}
+	for _, name := range protectedNames {
+		if l.Name == name {
+			return false
+		}
+	}
+	return true
 }
 
 func FilterListeners(in map[string]Listener, predicate ListenerPredicate) map[string]Listener {
